// THIS FILE IS GENERATED. ONE SHOULD NOT MODIFY IT
//! This module provides terms for `The Geonames ontology` vocabulary
//!
//! This module requires `ns-gn` feature to be enabled.
//!
//! ## Vocabulary:
//!
//! |||
//! |-----|-----|
//! |**Title**|The Geonames ontology|
//! |**Prefix**|gn|
//! |**Namespace base IRI**|<http://www.geonames.org/ontology#>|
//! |**Description**|The Geonames ontologies provides elements of description for geographical features, in particular those defined in the geonames.org data base|
//! |**Is defined by**|<http://www.geonames.org/ontology#>|
//!

use crate::namespace;

namespace!(
    "http://www.geonames.org/ontology#",;
    /// ``: 
    NAMESPACE_BASE, "",
    /// `A`: country, state, region ...
    A, "A",
    /// `A.ADM1`: 
    A_ADM1, "A.ADM1",
    /// `A.ADM1H`: 
    A_ADM1H, "A.ADM1H",
    /// `A.ADM2`: 
    A_ADM2, "A.ADM2",
    /// `A.ADM2H`: 
    A_ADM2H, "A.ADM2H",
    /// `A.ADM3`: 
    A_ADM3, "A.ADM3",
    /// `A.ADM3H`: 
    A_ADM3H, "A.ADM3H",
    /// `A.ADM4`: 
    A_ADM4, "A.ADM4",
    /// `A.ADM4H`: 
    A_ADM4H, "A.ADM4H",
    /// `A.ADM5`: 
    A_ADM5, "A.ADM5",
    /// `A.ADMD`: 
    A_ADMD, "A.ADMD",
    /// `A.ADMH`: 
    A_ADMH, "A.ADMH",
    /// `A.LTER`: 
    A_LTER, "A.LTER",
    /// `A.PCL`: 
    A_PCL, "A.PCL",
    /// `A.PCLD`: 
    A_PCLD, "A.PCLD",
    /// `A.PCLF`: 
    A_PCLF, "A.PCLF",
    /// `A.PCLH`: 
    A_PCLH, "A.PCLH",
    /// `A.PCLI`: 
    A_PCLI, "A.PCLI",
    /// `A.PCLIX`: 
    A_PCLIX, "A.PCLIX",
    /// `A.PCLS`: 
    A_PCLS, "A.PCLS",
    /// `A.PPCLH`: 
    A_PPCLH, "A.PPCLH",
    /// `A.PPLH`: 
    A_PPLH, "A.PPLH",
    /// `A.PRSH`: 
    A_PRSH, "A.PRSH",
    /// `A.TERR`: 
    A_TERR, "A.TERR",
    /// `A.ZN`: 
    A_ZN, "A.ZN",
    /// `A.ZNB`: 
    A_ZNB, "A.ZNB",
    /// `Class`: A class of features.
    Class, "Class",
    /// `Code`: A feature code.
    Code, "Code",
    /// `Feature`: A geographical feature
    Feature, "Feature",
    /// `Geonames Feature`: A feature described in geonames database, uniquely defined by its geonames identifier
    GeonamesFeature, "GeonamesFeature",
    /// `H`: stream, lake, ...
    H, "H",
    /// `H.AIRS`: 
    H_AIRS, "H.AIRS",
    /// `H.ANCH`: 
    H_ANCH, "H.ANCH",
    /// `H.BAY`: 
    H_BAY, "H.BAY",
    /// `H.BAYS`: 
    H_BAYS, "H.BAYS",
    /// `H.BGHT`: 
    H_BGHT, "H.BGHT",
    /// `H.BNK`: 
    H_BNK, "H.BNK",
    /// `H.BNKR`: 
    H_BNKR, "H.BNKR",
    /// `H.BNKX`: 
    H_BNKX, "H.BNKX",
    /// `H.BOG`: 
    H_BOG, "H.BOG",
    /// `H.CAPG`: 
    H_CAPG, "H.CAPG",
    /// `H.CHN`: 
    H_CHN, "H.CHN",
    /// `H.CHNL`: 
    H_CHNL, "H.CHNL",
    /// `H.CHNM`: 
    H_CHNM, "H.CHNM",
    /// `H.CHNN`: 
    H_CHNN, "H.CHNN",
    /// `H.CNFL`: 
    H_CNFL, "H.CNFL",
    /// `H.CNL`: 
    H_CNL, "H.CNL",
    /// `H.CNLA`: 
    H_CNLA, "H.CNLA",
    /// `H.CNLB`: 
    H_CNLB, "H.CNLB",
    /// `H.CNLD`: 
    H_CNLD, "H.CNLD",
    /// `H.CNLI`: 
    H_CNLI, "H.CNLI",
    /// `H.CNLN`: 
    H_CNLN, "H.CNLN",
    /// `H.CNLQ`: 
    H_CNLQ, "H.CNLQ",
    /// `H.CNLSB`: 
    H_CNLSB, "H.CNLSB",
    /// `H.CNLX`: 
    H_CNLX, "H.CNLX",
    /// `H.COVE`: 
    H_COVE, "H.COVE",
    /// `H.CRKT`: 
    H_CRKT, "H.CRKT",
    /// `H.CRNT`: 
    H_CRNT, "H.CRNT",
    /// `H.CUTF`: 
    H_CUTF, "H.CUTF",
    /// `H.DCK`: 
    H_DCK, "H.DCK",
    /// `H.DCKB`: 
    H_DCKB, "H.DCKB",
    /// `H.DOMG`: 
    H_DOMG, "H.DOMG",
    /// `H.DPRG`: 
    H_DPRG, "H.DPRG",
    /// `H.DTCH`: 
    H_DTCH, "H.DTCH",
    /// `H.DTCHD`: 
    H_DTCHD, "H.DTCHD",
    /// `H.DTCHI`: 
    H_DTCHI, "H.DTCHI",
    /// `H.DTCHM`: 
    H_DTCHM, "H.DTCHM",
    /// `H.ESTY`: 
    H_ESTY, "H.ESTY",
    /// `H.FISH`: 
    H_FISH, "H.FISH",
    /// `H.FJD`: 
    H_FJD, "H.FJD",
    /// `H.FJDS`: 
    H_FJDS, "H.FJDS",
    /// `H.FLLS`: 
    H_FLLS, "H.FLLS",
    /// `H.FLLSX`: 
    H_FLLSX, "H.FLLSX",
    /// `H.FLTM`: 
    H_FLTM, "H.FLTM",
    /// `H.FLTT`: 
    H_FLTT, "H.FLTT",
    /// `H.GLCR`: 
    H_GLCR, "H.GLCR",
    /// `H.GULF`: 
    H_GULF, "H.GULF",
    /// `H.GYSR`: 
    H_GYSR, "H.GYSR",
    /// `H.HBR`: 
    H_HBR, "H.HBR",
    /// `H.HBRX`: 
    H_HBRX, "H.HBRX",
    /// `H.INLT`: 
    H_INLT, "H.INLT",
    /// `H.INLTQ`: 
    H_INLTQ, "H.INLTQ",
    /// `H.LBED`: 
    H_LBED, "H.LBED",
    /// `H.LGN`: 
    H_LGN, "H.LGN",
    /// `H.LGNS`: 
    H_LGNS, "H.LGNS",
    /// `H.LGNX`: 
    H_LGNX, "H.LGNX",
    /// `H.LK`: 
    H_LK, "H.LK",
    /// `H.LKC`: 
    H_LKC, "H.LKC",
    /// `H.LKI`: 
    H_LKI, "H.LKI",
    /// `H.LKN`: 
    H_LKN, "H.LKN",
    /// `H.LKNI`: 
    H_LKNI, "H.LKNI",
    /// `H.LKO`: 
    H_LKO, "H.LKO",
    /// `H.LKOI`: 
    H_LKOI, "H.LKOI",
    /// `H.LKS`: 
    H_LKS, "H.LKS",
    /// `H.LKSB`: 
    H_LKSB, "H.LKSB",
    /// `H.LKSC`: 
    H_LKSC, "H.LKSC",
    /// `H.LKSI`: 
    H_LKSI, "H.LKSI",
    /// `H.LKSN`: 
    H_LKSN, "H.LKSN",
    /// `H.LKSNI`: 
    H_LKSNI, "H.LKSNI",
    /// `H.LKX`: 
    H_LKX, "H.LKX",
    /// `H.MFGN`: 
    H_MFGN, "H.MFGN",
    /// `H.MGV`: 
    H_MGV, "H.MGV",
    /// `H.MOOR`: 
    H_MOOR, "H.MOOR",
    /// `H.MRSH`: 
    H_MRSH, "H.MRSH",
    /// `H.MRSHN`: 
    H_MRSHN, "H.MRSHN",
    /// `H.NRWS`: 
    H_NRWS, "H.NRWS",
    /// `H.OCN`: 
    H_OCN, "H.OCN",
    /// `H.OVF`: 
    H_OVF, "H.OVF",
    /// `H.PND`: 
    H_PND, "H.PND",
    /// `H.PNDI`: 
    H_PNDI, "H.PNDI",
    /// `H.PNDN`: 
    H_PNDN, "H.PNDN",
    /// `H.PNDNI`: 
    H_PNDNI, "H.PNDNI",
    /// `H.PNDS`: 
    H_PNDS, "H.PNDS",
    /// `H.PNDSF`: 
    H_PNDSF, "H.PNDSF",
    /// `H.PNDSI`: 
    H_PNDSI, "H.PNDSI",
    /// `H.PNDSN`: 
    H_PNDSN, "H.PNDSN",
    /// `H.POOL`: 
    H_POOL, "H.POOL",
    /// `H.POOLI`: 
    H_POOLI, "H.POOLI",
    /// `H.RCH`: 
    H_RCH, "H.RCH",
    /// `H.RDGG`: 
    H_RDGG, "H.RDGG",
    /// `H.RDST`: 
    H_RDST, "H.RDST",
    /// `H.RF`: 
    H_RF, "H.RF",
    /// `H.RFC`: 
    H_RFC, "H.RFC",
    /// `H.RFX`: 
    H_RFX, "H.RFX",
    /// `H.RPDS`: 
    H_RPDS, "H.RPDS",
    /// `H.RSV`: 
    H_RSV, "H.RSV",
    /// `H.RSVI`: 
    H_RSVI, "H.RSVI",
    /// `H.RSVT`: 
    H_RSVT, "H.RSVT",
    /// `H.RVN`: 
    H_RVN, "H.RVN",
    /// `H.SBKH`: 
    H_SBKH, "H.SBKH",
    /// `H.SD`: 
    H_SD, "H.SD",
    /// `H.SEA`: 
    H_SEA, "H.SEA",
    /// `H.SHOL`: 
    H_SHOL, "H.SHOL",
    /// `H.SILL`: 
    H_SILL, "H.SILL",
    /// `H.SPNG`: 
    H_SPNG, "H.SPNG",
    /// `H.SPNS`: 
    H_SPNS, "H.SPNS",
    /// `H.SPNT`: 
    H_SPNT, "H.SPNT",
    /// `H.STM`: 
    H_STM, "H.STM",
    /// `H.STMA`: 
    H_STMA, "H.STMA",
    /// `H.STMB`: 
    H_STMB, "H.STMB",
    /// `H.STMC`: 
    H_STMC, "H.STMC",
    /// `H.STMD`: 
    H_STMD, "H.STMD",
    /// `H.STMH`: 
    H_STMH, "H.STMH",
    /// `H.STMI`: 
    H_STMI, "H.STMI",
    /// `H.STMIX`: 
    H_STMIX, "H.STMIX",
    /// `H.STMM`: 
    H_STMM, "H.STMM",
    /// `H.STMQ`: 
    H_STMQ, "H.STMQ",
    /// `H.STMS`: 
    H_STMS, "H.STMS",
    /// `H.STMSB`: 
    H_STMSB, "H.STMSB",
    /// `H.STMX`: 
    H_STMX, "H.STMX",
    /// `H.STRT`: 
    H_STRT, "H.STRT",
    /// `H.SWMP`: 
    H_SWMP, "H.SWMP",
    /// `H.SYSI`: 
    H_SYSI, "H.SYSI",
    /// `H.TNLC`: 
    H_TNLC, "H.TNLC",
    /// `H.WAD`: 
    H_WAD, "H.WAD",
    /// `H.WADB`: 
    H_WADB, "H.WADB",
    /// `H.WADJ`: 
    H_WADJ, "H.WADJ",
    /// `H.WADM`: 
    H_WADM, "H.WADM",
    /// `H.WADS`: 
    H_WADS, "H.WADS",
    /// `H.WADX`: 
    H_WADX, "H.WADX",
    /// `H.WHRL`: 
    H_WHRL, "H.WHRL",
    /// `H.WLL`: 
    H_WLL, "H.WLL",
    /// `H.WLLQ`: 
    H_WLLQ, "H.WLLQ",
    /// `H.WLLS`: 
    H_WLLS, "H.WLLS",
    /// `H.WTLD`: 
    H_WTLD, "H.WTLD",
    /// `H.WTLDI`: 
    H_WTLDI, "H.WTLDI",
    /// `H.WTRC`: 
    H_WTRC, "H.WTRC",
    /// `H.WTRH`: 
    H_WTRH, "H.WTRH",
    /// `L`: parks,area, ...
    L, "L",
    /// `L.AGRC`: 
    L_AGRC, "L.AGRC",
    /// `L.AMUS`: 
    L_AMUS, "L.AMUS",
    /// `L.AREA`: 
    L_AREA, "L.AREA",
    /// `L.BSND`: 
    L_BSND, "L.BSND",
    /// `L.BSNP`: 
    L_BSNP, "L.BSNP",
    /// `L.BTL`: 
    L_BTL, "L.BTL",
    /// `L.CLG`: 
    L_CLG, "L.CLG",
    /// `L.CMN`: 
    L_CMN, "L.CMN",
    /// `L.CNS`: 
    L_CNS, "L.CNS",
    /// `L.COLF`: 
    L_COLF, "L.COLF",
    /// `L.CONT`: 
    L_CONT, "L.CONT",
    /// `L.CST`: 
    L_CST, "L.CST",
    /// `L.CTRB`: 
    L_CTRB, "L.CTRB",
    /// `L.DEVH`: 
    L_DEVH, "L.DEVH",
    /// `L.FLD`: 
    L_FLD, "L.FLD",
    /// `L.FLDI`: 
    L_FLDI, "L.FLDI",
    /// `L.GASF`: 
    L_GASF, "L.GASF",
    /// `L.GRAZ`: 
    L_GRAZ, "L.GRAZ",
    /// `L.GVL`: 
    L_GVL, "L.GVL",
    /// `L.INDS`: 
    L_INDS, "L.INDS",
    /// `L.LAND`: 
    L_LAND, "L.LAND",
    /// `L.LCTY`: 
    L_LCTY, "L.LCTY",
    /// `L.MILB`: 
    L_MILB, "L.MILB",
    /// `L.MNA`: 
    L_MNA, "L.MNA",
    /// `L.MVA`: 
    L_MVA, "L.MVA",
    /// `L.NVB`: 
    L_NVB, "L.NVB",
    /// `L.OAS`: 
    L_OAS, "L.OAS",
    /// `L.OILF`: 
    L_OILF, "L.OILF",
    /// `L.PEAT`: 
    L_PEAT, "L.PEAT",
    /// `L.PRK`: 
    L_PRK, "L.PRK",
    /// `L.PRT`: 
    L_PRT, "L.PRT",
    /// `L.QCKS`: 
    L_QCKS, "L.QCKS",
    /// `L.REP`: 
    L_REP, "L.REP",
    /// `L.RES`: 
    L_RES, "L.RES",
    /// `L.RESA`: 
    L_RESA, "L.RESA",
    /// `L.RESF`: 
    L_RESF, "L.RESF",
    /// `L.RESH`: 
    L_RESH, "L.RESH",
    /// `L.RESN`: 
    L_RESN, "L.RESN",
    /// `L.RESP`: 
    L_RESP, "L.RESP",
    /// `L.RESV`: 
    L_RESV, "L.RESV",
    /// `L.RESW`: 
    L_RESW, "L.RESW",
    /// `L.RGN`: 
    L_RGN, "L.RGN",
    /// `L.RGNE`: 
    L_RGNE, "L.RGNE",
    /// `L.RGNH`: 
    L_RGNH, "L.RGNH",
    /// `L.RGNL`: 
    L_RGNL, "L.RGNL",
    /// `L.RNGA`: 
    L_RNGA, "L.RNGA",
    /// `L.SALT`: 
    L_SALT, "L.SALT",
    /// `L.SNOW`: 
    L_SNOW, "L.SNOW",
    /// `L.TRB`: 
    L_TRB, "L.TRB",
    /// `L.ZZZZZ`: 
    L_ZZZZZ, "L.ZZZZZ",
    /// `Map`: A Web page displaying a map
    Map, "Map",
    /// `Marc-Wick`: 
    Marc_Wick, "Marc-Wick",
    /// `P`: city, village,...
    P, "P",
    /// `P.PPL`: 
    P_PPL, "P.PPL",
    /// `P.PPLA`: 
    P_PPLA, "P.PPLA",
    /// `P.PPLA2`: 
    P_PPLA2, "P.PPLA2",
    /// `P.PPLA3`: 
    P_PPLA3, "P.PPLA3",
    /// `P.PPLA4`: 
    P_PPLA4, "P.PPLA4",
    /// `P.PPLC`: 
    P_PPLC, "P.PPLC",
    /// `P.PPLF`: 
    P_PPLF, "P.PPLF",
    /// `P.PPLG`: 
    P_PPLG, "P.PPLG",
    /// `P.PPLL`: 
    P_PPLL, "P.PPLL",
    /// `P.PPLQ`: 
    P_PPLQ, "P.PPLQ",
    /// `P.PPLR`: 
    P_PPLR, "P.PPLR",
    /// `P.PPLS`: 
    P_PPLS, "P.PPLS",
    /// `P.PPLW`: 
    P_PPLW, "P.PPLW",
    /// `P.PPLX`: 
    P_PPLX, "P.PPLX",
    /// `P.STLMT`: 
    P_STLMT, "P.STLMT",
    /// `R`: road, railroad, ...
    R, "R",
    /// `R.CSWY`: 
    R_CSWY, "R.CSWY",
    /// `R.CSWYQ`: 
    R_CSWYQ, "R.CSWYQ",
    /// `R.OILP`: 
    R_OILP, "R.OILP",
    /// `R.PRMN`: 
    R_PRMN, "R.PRMN",
    /// `R.PTGE`: 
    R_PTGE, "R.PTGE",
    /// `R.RD`: 
    R_RD, "R.RD",
    /// `R.RDA`: 
    R_RDA, "R.RDA",
    /// `R.RDB`: 
    R_RDB, "R.RDB",
    /// `R.RDCUT`: 
    R_RDCUT, "R.RDCUT",
    /// `R.RDJCT`: 
    R_RDJCT, "R.RDJCT",
    /// `R.RJCT`: 
    R_RJCT, "R.RJCT",
    /// `R.RR`: 
    R_RR, "R.RR",
    /// `R.RRQ`: 
    R_RRQ, "R.RRQ",
    /// `R.RTE`: 
    R_RTE, "R.RTE",
    /// `R.RYD`: 
    R_RYD, "R.RYD",
    /// `R.ST`: 
    R_ST, "R.ST",
    /// `R.STKR`: 
    R_STKR, "R.STKR",
    /// `R.TNL`: 
    R_TNL, "R.TNL",
    /// `R.TNLN`: 
    R_TNLN, "R.TNLN",
    /// `R.TNLRD`: 
    R_TNLRD, "R.TNLRD",
    /// `R.TNLRR`: 
    R_TNLRR, "R.TNLRR",
    /// `R.TNLS`: 
    R_TNLS, "R.TNLS",
    /// `R.TRL`: 
    R_TRL, "R.TRL",
    /// `RDF Data`: A Document containing RDF description of one or several features.
    RDFData, "RDFData",
    /// `S`: spot, building, farm, ...
    S, "S",
    /// `S.ADMF`: 
    S_ADMF, "S.ADMF",
    /// `S.AGRF`: 
    S_AGRF, "S.AGRF",
    /// `S.AIRB`: 
    S_AIRB, "S.AIRB",
    /// `S.AIRF`: 
    S_AIRF, "S.AIRF",
    /// `S.AIRH`: 
    S_AIRH, "S.AIRH",
    /// `S.AIRP`: 
    S_AIRP, "S.AIRP",
    /// `S.AIRQ`: 
    S_AIRQ, "S.AIRQ",
    /// `S.AMTH`: 
    S_AMTH, "S.AMTH",
    /// `S.ANS`: 
    S_ANS, "S.ANS",
    /// `S.AQC`: 
    S_AQC, "S.AQC",
    /// `S.ARCH`: 
    S_ARCH, "S.ARCH",
    /// `S.ASTR`: 
    S_ASTR, "S.ASTR",
    /// `S.ASYL`: 
    S_ASYL, "S.ASYL",
    /// `S.ATHF`: 
    S_ATHF, "S.ATHF",
    /// `S.ATM`: 
    S_ATM, "S.ATM",
    /// `S.BANK`: 
    S_BANK, "S.BANK",
    /// `S.BCN`: 
    S_BCN, "S.BCN",
    /// `S.BDG`: 
    S_BDG, "S.BDG",
    /// `S.BDGQ`: 
    S_BDGQ, "S.BDGQ",
    /// `S.BLDG`: 
    S_BLDG, "S.BLDG",
    /// `S.BLDO`: 
    S_BLDO, "S.BLDO",
    /// `S.BP`: 
    S_BP, "S.BP",
    /// `S.BRKS`: 
    S_BRKS, "S.BRKS",
    /// `S.BRKW`: 
    S_BRKW, "S.BRKW",
    /// `S.BSTN`: 
    S_BSTN, "S.BSTN",
    /// `S.BTYD`: 
    S_BTYD, "S.BTYD",
    /// `S.BUR`: 
    S_BUR, "S.BUR",
    /// `S.BUSTN`: 
    S_BUSTN, "S.BUSTN",
    /// `S.BUSTP`: 
    S_BUSTP, "S.BUSTP",
    /// `S.CARN`: 
    S_CARN, "S.CARN",
    /// `S.CAVE`: 
    S_CAVE, "S.CAVE",
    /// `S.CCL`: 
    S_CCL, "S.CCL",
    /// `S.CH`: 
    S_CH, "S.CH",
    /// `S.CMP`: 
    S_CMP, "S.CMP",
    /// `S.CMPL`: 
    S_CMPL, "S.CMPL",
    /// `S.CMPLA`: 
    S_CMPLA, "S.CMPLA",
    /// `S.CMPMN`: 
    S_CMPMN, "S.CMPMN",
    /// `S.CMPO`: 
    S_CMPO, "S.CMPO",
    /// `S.CMPQ`: 
    S_CMPQ, "S.CMPQ",
    /// `S.CMPRF`: 
    S_CMPRF, "S.CMPRF",
    /// `S.CMTY`: 
    S_CMTY, "S.CMTY",
    /// `S.COMC`: 
    S_COMC, "S.COMC",
    /// `S.CRRL`: 
    S_CRRL, "S.CRRL",
    /// `S.CSNO`: 
    S_CSNO, "S.CSNO",
    /// `S.CSTL`: 
    S_CSTL, "S.CSTL",
    /// `S.CSTM`: 
    S_CSTM, "S.CSTM",
    /// `S.CTHSE`: 
    S_CTHSE, "S.CTHSE",
    /// `S.CTRA`: 
    S_CTRA, "S.CTRA",
    /// `S.CTRCM`: 
    S_CTRCM, "S.CTRCM",
    /// `S.CTRF`: 
    S_CTRF, "S.CTRF",
    /// `S.CTRM`: 
    S_CTRM, "S.CTRM",
    /// `S.CTRR`: 
    S_CTRR, "S.CTRR",
    /// `S.CTRS`: 
    S_CTRS, "S.CTRS",
    /// `S.CVNT`: 
    S_CVNT, "S.CVNT",
    /// `S.DAM`: 
    S_DAM, "S.DAM",
    /// `S.DAMQ`: 
    S_DAMQ, "S.DAMQ",
    /// `S.DAMSB`: 
    S_DAMSB, "S.DAMSB",
    /// `S.DARY`: 
    S_DARY, "S.DARY",
    /// `S.DCKD`: 
    S_DCKD, "S.DCKD",
    /// `S.DCKY`: 
    S_DCKY, "S.DCKY",
    /// `S.DIKE`: 
    S_DIKE, "S.DIKE",
    /// `S.DIP`: 
    S_DIP, "S.DIP",
    /// `S.DPOF`: 
    S_DPOF, "S.DPOF",
    /// `S.EST`: 
    S_EST, "S.EST",
    /// `S.ESTB`: 
    S_ESTB, "S.ESTB",
    /// `S.ESTC`: 
    S_ESTC, "S.ESTC",
    /// `S.ESTO`: 
    S_ESTO, "S.ESTO",
    /// `S.ESTR`: 
    S_ESTR, "S.ESTR",
    /// `S.ESTSG`: 
    S_ESTSG, "S.ESTSG",
    /// `S.ESTSL`: 
    S_ESTSL, "S.ESTSL",
    /// `S.ESTT`: 
    S_ESTT, "S.ESTT",
    /// `S.ESTX`: 
    S_ESTX, "S.ESTX",
    /// `S.FCL`: 
    S_FCL, "S.FCL",
    /// `S.FNDY`: 
    S_FNDY, "S.FNDY",
    /// `S.FRM`: 
    S_FRM, "S.FRM",
    /// `S.FRMQ`: 
    S_FRMQ, "S.FRMQ",
    /// `S.FRMS`: 
    S_FRMS, "S.FRMS",
    /// `S.FRMT`: 
    S_FRMT, "S.FRMT",
    /// `S.FT`: 
    S_FT, "S.FT",
    /// `S.FY`: 
    S_FY, "S.FY",
    /// `S.GATE`: 
    S_GATE, "S.GATE",
    /// `S.GDN`: 
    S_GDN, "S.GDN",
    /// `S.GHAT`: 
    S_GHAT, "S.GHAT",
    /// `S.GHSE`: 
    S_GHSE, "S.GHSE",
    /// `S.GOSP`: 
    S_GOSP, "S.GOSP",
    /// `S.GOVL`: 
    S_GOVL, "S.GOVL",
    /// `S.GRVE`: 
    S_GRVE, "S.GRVE",
    /// `S.HERM`: 
    S_HERM, "S.HERM",
    /// `S.HLT`: 
    S_HLT, "S.HLT",
    /// `S.HMSD`: 
    S_HMSD, "S.HMSD",
    /// `S.HSE`: 
    S_HSE, "S.HSE",
    /// `S.HSEC`: 
    S_HSEC, "S.HSEC",
    /// `S.HSP`: 
    S_HSP, "S.HSP",
    /// `S.HSPC`: 
    S_HSPC, "S.HSPC",
    /// `S.HSPD`: 
    S_HSPD, "S.HSPD",
    /// `S.HSPL`: 
    S_HSPL, "S.HSPL",
    /// `S.HSTS`: 
    S_HSTS, "S.HSTS",
    /// `S.HTL`: 
    S_HTL, "S.HTL",
    /// `S.HUT`: 
    S_HUT, "S.HUT",
    /// `S.HUTS`: 
    S_HUTS, "S.HUTS",
    /// `S.INSM`: 
    S_INSM, "S.INSM",
    /// `S.ITTR`: 
    S_ITTR, "S.ITTR",
    /// `S.JTY`: 
    S_JTY, "S.JTY",
    /// `S.LDNG`: 
    S_LDNG, "S.LDNG",
    /// `S.LEPC`: 
    S_LEPC, "S.LEPC",
    /// `S.LIBR`: 
    S_LIBR, "S.LIBR",
    /// `S.LNDF`: 
    S_LNDF, "S.LNDF",
    /// `S.LOCK`: 
    S_LOCK, "S.LOCK",
    /// `S.LTHSE`: 
    S_LTHSE, "S.LTHSE",
    /// `S.MALL`: 
    S_MALL, "S.MALL",
    /// `S.MAR`: 
    S_MAR, "S.MAR",
    /// `S.MFG`: 
    S_MFG, "S.MFG",
    /// `S.MFGB`: 
    S_MFGB, "S.MFGB",
    /// `S.MFGC`: 
    S_MFGC, "S.MFGC",
    /// `S.MFGCU`: 
    S_MFGCU, "S.MFGCU",
    /// `S.MFGLM`: 
    S_MFGLM, "S.MFGLM",
    /// `S.MFGM`: 
    S_MFGM, "S.MFGM",
    /// `S.MFGPH`: 
    S_MFGPH, "S.MFGPH",
    /// `S.MFGQ`: 
    S_MFGQ, "S.MFGQ",
    /// `S.MFGSG`: 
    S_MFGSG, "S.MFGSG",
    /// `S.MKT`: 
    S_MKT, "S.MKT",
    /// `S.ML`: 
    S_ML, "S.ML",
    /// `S.MLM`: 
    S_MLM, "S.MLM",
    /// `S.MLO`: 
    S_MLO, "S.MLO",
    /// `S.MLSG`: 
    S_MLSG, "S.MLSG",
    /// `S.MLSGQ`: 
    S_MLSGQ, "S.MLSGQ",
    /// `S.MLSW`: 
    S_MLSW, "S.MLSW",
    /// `S.MLWND`: 
    S_MLWND, "S.MLWND",
    /// `S.MLWTR`: 
    S_MLWTR, "S.MLWTR",
    /// `S.MN`: 
    S_MN, "S.MN",
    /// `S.MNAU`: 
    S_MNAU, "S.MNAU",
    /// `S.MNC`: 
    S_MNC, "S.MNC",
    /// `S.MNCR`: 
    S_MNCR, "S.MNCR",
    /// `S.MNCU`: 
    S_MNCU, "S.MNCU",
    /// `S.MNDT`: 
    S_MNDT, "S.MNDT",
    /// `S.MNFE`: 
    S_MNFE, "S.MNFE",
    /// `S.MNMT`: 
    S_MNMT, "S.MNMT",
    /// `S.MNN`: 
    S_MNN, "S.MNN",
    /// `S.MNNI`: 
    S_MNNI, "S.MNNI",
    /// `S.MNPB`: 
    S_MNPB, "S.MNPB",
    /// `S.MNPL`: 
    S_MNPL, "S.MNPL",
    /// `S.MNQ`: 
    S_MNQ, "S.MNQ",
    /// `S.MNQR`: 
    S_MNQR, "S.MNQR",
    /// `S.MNSN`: 
    S_MNSN, "S.MNSN",
    /// `S.MOLE`: 
    S_MOLE, "S.MOLE",
    /// `S.MSQE`: 
    S_MSQE, "S.MSQE",
    /// `S.MSSN`: 
    S_MSSN, "S.MSSN",
    /// `S.MSSNQ`: 
    S_MSSNQ, "S.MSSNQ",
    /// `S.MSTY`: 
    S_MSTY, "S.MSTY",
    /// `S.MTRO`: 
    S_MTRO, "S.MTRO",
    /// `S.MUS`: 
    S_MUS, "S.MUS",
    /// `S.NOV`: 
    S_NOV, "S.NOV",
    /// `S.NSY`: 
    S_NSY, "S.NSY",
    /// `S.OBPT`: 
    S_OBPT, "S.OBPT",
    /// `S.OBS`: 
    S_OBS, "S.OBS",
    /// `S.OBSR`: 
    S_OBSR, "S.OBSR",
    /// `S.OILJ`: 
    S_OILJ, "S.OILJ",
    /// `S.OILQ`: 
    S_OILQ, "S.OILQ",
    /// `S.OILR`: 
    S_OILR, "S.OILR",
    /// `S.OILT`: 
    S_OILT, "S.OILT",
    /// `S.OILW`: 
    S_OILW, "S.OILW",
    /// `S.OPRA`: 
    S_OPRA, "S.OPRA",
    /// `S.PAL`: 
    S_PAL, "S.PAL",
    /// `S.PGDA`: 
    S_PGDA, "S.PGDA",
    /// `S.PIER`: 
    S_PIER, "S.PIER",
    /// `S.PKLT`: 
    S_PKLT, "S.PKLT",
    /// `S.PMPO`: 
    S_PMPO, "S.PMPO",
    /// `S.PMPW`: 
    S_PMPW, "S.PMPW",
    /// `S.PO`: 
    S_PO, "S.PO",
    /// `S.PP`: 
    S_PP, "S.PP",
    /// `S.PPQ`: 
    S_PPQ, "S.PPQ",
    /// `S.PRKGT`: 
    S_PRKGT, "S.PRKGT",
    /// `S.PRKHQ`: 
    S_PRKHQ, "S.PRKHQ",
    /// `S.PRN`: 
    S_PRN, "S.PRN",
    /// `S.PRNJ`: 
    S_PRNJ, "S.PRNJ",
    /// `S.PRNQ`: 
    S_PRNQ, "S.PRNQ",
    /// `S.PS`: 
    S_PS, "S.PS",
    /// `S.PSH`: 
    S_PSH, "S.PSH",
    /// `S.PSTB`: 
    S_PSTB, "S.PSTB",
    /// `S.PSTC`: 
    S_PSTC, "S.PSTC",
    /// `S.PSTP`: 
    S_PSTP, "S.PSTP",
    /// `S.PYR`: 
    S_PYR, "S.PYR",
    /// `S.PYRS`: 
    S_PYRS, "S.PYRS",
    /// `S.QUAY`: 
    S_QUAY, "S.QUAY",
    /// `S.RDCR`: 
    S_RDCR, "S.RDCR",
    /// `S.RECG`: 
    S_RECG, "S.RECG",
    /// `S.RECR`: 
    S_RECR, "S.RECR",
    /// `S.REST`: 
    S_REST, "S.REST",
    /// `S.RET`: 
    S_RET, "S.RET",
    /// `S.RHSE`: 
    S_RHSE, "S.RHSE",
    /// `S.RKRY`: 
    S_RKRY, "S.RKRY",
    /// `S.RLG`: 
    S_RLG, "S.RLG",
    /// `S.RLGR`: 
    S_RLGR, "S.RLGR",
    /// `S.RNCH`: 
    S_RNCH, "S.RNCH",
    /// `S.RSD`: 
    S_RSD, "S.RSD",
    /// `S.RSGNL`: 
    S_RSGNL, "S.RSGNL",
    /// `S.RSRT`: 
    S_RSRT, "S.RSRT",
    /// `S.RSTN`: 
    S_RSTN, "S.RSTN",
    /// `S.RSTNQ`: 
    S_RSTNQ, "S.RSTNQ",
    /// `S.RSTP`: 
    S_RSTP, "S.RSTP",
    /// `S.RSTPQ`: 
    S_RSTPQ, "S.RSTPQ",
    /// `S.RUIN`: 
    S_RUIN, "S.RUIN",
    /// `S.SCH`: 
    S_SCH, "S.SCH",
    /// `S.SCHA`: 
    S_SCHA, "S.SCHA",
    /// `S.SCHC`: 
    S_SCHC, "S.SCHC",
    /// `S.SCHD`: 
    S_SCHD, "S.SCHD",
    /// `S.SCHL`: 
    S_SCHL, "S.SCHL",
    /// `S.SCHM`: 
    S_SCHM, "S.SCHM",
    /// `S.SCHN`: 
    S_SCHN, "S.SCHN",
    /// `S.SCHT`: 
    S_SCHT, "S.SCHT",
    /// `S.SECP`: 
    S_SECP, "S.SECP",
    /// `S.SHPF`: 
    S_SHPF, "S.SHPF",
    /// `S.SHRN`: 
    S_SHRN, "S.SHRN",
    /// `S.SHSE`: 
    S_SHSE, "S.SHSE",
    /// `S.SLCE`: 
    S_SLCE, "S.SLCE",
    /// `S.SNTR`: 
    S_SNTR, "S.SNTR",
    /// `S.SPA`: 
    S_SPA, "S.SPA",
    /// `S.SPLY`: 
    S_SPLY, "S.SPLY",
    /// `S.SQR`: 
    S_SQR, "S.SQR",
    /// `S.STBL`: 
    S_STBL, "S.STBL",
    /// `S.STDM`: 
    S_STDM, "S.STDM",
    /// `S.STNB`: 
    S_STNB, "S.STNB",
    /// `S.STNC`: 
    S_STNC, "S.STNC",
    /// `S.STNE`: 
    S_STNE, "S.STNE",
    /// `S.STNF`: 
    S_STNF, "S.STNF",
    /// `S.STNI`: 
    S_STNI, "S.STNI",
    /// `S.STNM`: 
    S_STNM, "S.STNM",
    /// `S.STNR`: 
    S_STNR, "S.STNR",
    /// `S.STNS`: 
    S_STNS, "S.STNS",
    /// `S.STNW`: 
    S_STNW, "S.STNW",
    /// `S.STPS`: 
    S_STPS, "S.STPS",
    /// `S.SWT`: 
    S_SWT, "S.SWT",
    /// `S.THTR`: 
    S_THTR, "S.THTR",
    /// `S.TMB`: 
    S_TMB, "S.TMB",
    /// `S.TMPL`: 
    S_TMPL, "S.TMPL",
    /// `S.TNKD`: 
    S_TNKD, "S.TNKD",
    /// `S.TOWR`: 
    S_TOWR, "S.TOWR",
    /// `S.TRANT`: 
    S_TRANT, "S.TRANT",
    /// `S.TRIG`: 
    S_TRIG, "S.TRIG",
    /// `S.TRMO`: 
    S_TRMO, "S.TRMO",
    /// `S.TWO`: 
    S_TWO, "S.TWO",
    /// `S.UNIO`: 
    S_UNIO, "S.UNIO",
    /// `S.UNIP`: 
    S_UNIP, "S.UNIP",
    /// `S.UNIV`: 
    S_UNIV, "S.UNIV",
    /// `S.USGE`: 
    S_USGE, "S.USGE",
    /// `S.VETF`: 
    S_VETF, "S.VETF",
    /// `S.WALL`: 
    S_WALL, "S.WALL",
    /// `S.WALLA`: 
    S_WALLA, "S.WALLA",
    /// `S.WEIR`: 
    S_WEIR, "S.WEIR",
    /// `S.WHRF`: 
    S_WHRF, "S.WHRF",
    /// `S.WRCK`: 
    S_WRCK, "S.WRCK",
    /// `S.WTRW`: 
    S_WTRW, "S.WTRW",
    /// `S.ZNF`: 
    S_ZNF, "S.ZNF",
    /// `S.ZOO`: 
    S_ZOO, "S.ZOO",
    /// `T`: mountain, hill, rock, ...
    T, "T",
    /// `T.ASPH`: 
    T_ASPH, "T.ASPH",
    /// `T.ATOL`: 
    T_ATOL, "T.ATOL",
    /// `T.BAR`: 
    T_BAR, "T.BAR",
    /// `T.BCH`: 
    T_BCH, "T.BCH",
    /// `T.BCHS`: 
    T_BCHS, "T.BCHS",
    /// `T.BDLD`: 
    T_BDLD, "T.BDLD",
    /// `T.BLDR`: 
    T_BLDR, "T.BLDR",
    /// `T.BLHL`: 
    T_BLHL, "T.BLHL",
    /// `T.BLOW`: 
    T_BLOW, "T.BLOW",
    /// `T.BNCH`: 
    T_BNCH, "T.BNCH",
    /// `T.BUTE`: 
    T_BUTE, "T.BUTE",
    /// `T.CAPE`: 
    T_CAPE, "T.CAPE",
    /// `T.CFT`: 
    T_CFT, "T.CFT",
    /// `T.CLDA`: 
    T_CLDA, "T.CLDA",
    /// `T.CLF`: 
    T_CLF, "T.CLF",
    /// `T.CNYN`: 
    T_CNYN, "T.CNYN",
    /// `T.CONE`: 
    T_CONE, "T.CONE",
    /// `T.CRDR`: 
    T_CRDR, "T.CRDR",
    /// `T.CRQ`: 
    T_CRQ, "T.CRQ",
    /// `T.CRQS`: 
    T_CRQS, "T.CRQS",
    /// `T.CRTR`: 
    T_CRTR, "T.CRTR",
    /// `T.CUET`: 
    T_CUET, "T.CUET",
    /// `T.DLTA`: 
    T_DLTA, "T.DLTA",
    /// `T.DPR`: 
    T_DPR, "T.DPR",
    /// `T.DSRT`: 
    T_DSRT, "T.DSRT",
    /// `T.DUNE`: 
    T_DUNE, "T.DUNE",
    /// `T.DVD`: 
    T_DVD, "T.DVD",
    /// `T.ERG`: 
    T_ERG, "T.ERG",
    /// `T.FAN`: 
    T_FAN, "T.FAN",
    /// `T.FORD`: 
    T_FORD, "T.FORD",
    /// `T.FSR`: 
    T_FSR, "T.FSR",
    /// `T.GAP`: 
    T_GAP, "T.GAP",
    /// `T.GRGE`: 
    T_GRGE, "T.GRGE",
    /// `T.HDLD`: 
    T_HDLD, "T.HDLD",
    /// `T.HLL`: 
    T_HLL, "T.HLL",
    /// `T.HLLS`: 
    T_HLLS, "T.HLLS",
    /// `T.HMCK`: 
    T_HMCK, "T.HMCK",
    /// `T.HMDA`: 
    T_HMDA, "T.HMDA",
    /// `T.INTF`: 
    T_INTF, "T.INTF",
    /// `T.ISL`: 
    T_ISL, "T.ISL",
    /// `T.ISLET`: 
    T_ISLET, "T.ISLET",
    /// `T.ISLF`: 
    T_ISLF, "T.ISLF",
    /// `T.ISLM`: 
    T_ISLM, "T.ISLM",
    /// `T.ISLS`: 
    T_ISLS, "T.ISLS",
    /// `T.ISLT`: 
    T_ISLT, "T.ISLT",
    /// `T.ISLX`: 
    T_ISLX, "T.ISLX",
    /// `T.ISTH`: 
    T_ISTH, "T.ISTH",
    /// `T.KRST`: 
    T_KRST, "T.KRST",
    /// `T.LAVA`: 
    T_LAVA, "T.LAVA",
    /// `T.LEV`: 
    T_LEV, "T.LEV",
    /// `T.MESA`: 
    T_MESA, "T.MESA",
    /// `T.MND`: 
    T_MND, "T.MND",
    /// `T.MRN`: 
    T_MRN, "T.MRN",
    /// `T.MT`: 
    T_MT, "T.MT",
    /// `T.MTS`: 
    T_MTS, "T.MTS",
    /// `T.NKM`: 
    T_NKM, "T.NKM",
    /// `T.NTK`: 
    T_NTK, "T.NTK",
    /// `T.NTKS`: 
    T_NTKS, "T.NTKS",
    /// `T.PAN`: 
    T_PAN, "T.PAN",
    /// `T.PANS`: 
    T_PANS, "T.PANS",
    /// `T.PASS`: 
    T_PASS, "T.PASS",
    /// `T.PEN`: 
    T_PEN, "T.PEN",
    /// `T.PENX`: 
    T_PENX, "T.PENX",
    /// `T.PK`: 
    T_PK, "T.PK",
    /// `T.PKS`: 
    T_PKS, "T.PKS",
    /// `T.PLAT`: 
    T_PLAT, "T.PLAT",
    /// `T.PLATX`: 
    T_PLATX, "T.PLATX",
    /// `T.PLDR`: 
    T_PLDR, "T.PLDR",
    /// `T.PLN`: 
    T_PLN, "T.PLN",
    /// `T.PLNX`: 
    T_PLNX, "T.PLNX",
    /// `T.PROM`: 
    T_PROM, "T.PROM",
    /// `T.PT`: 
    T_PT, "T.PT",
    /// `T.PTS`: 
    T_PTS, "T.PTS",
    /// `T.RDGB`: 
    T_RDGB, "T.RDGB",
    /// `T.RDGE`: 
    T_RDGE, "T.RDGE",
    /// `T.REG`: 
    T_REG, "T.REG",
    /// `T.RK`: 
    T_RK, "T.RK",
    /// `T.RKFL`: 
    T_RKFL, "T.RKFL",
    /// `T.RKS`: 
    T_RKS, "T.RKS",
    /// `T.SAND`: 
    T_SAND, "T.SAND",
    /// `T.SBED`: 
    T_SBED, "T.SBED",
    /// `T.SCRP`: 
    T_SCRP, "T.SCRP",
    /// `T.SDL`: 
    T_SDL, "T.SDL",
    /// `T.SHOR`: 
    T_SHOR, "T.SHOR",
    /// `T.SINK`: 
    T_SINK, "T.SINK",
    /// `T.SLID`: 
    T_SLID, "T.SLID",
    /// `T.SLP`: 
    T_SLP, "T.SLP",
    /// `T.SPIT`: 
    T_SPIT, "T.SPIT",
    /// `T.SPUR`: 
    T_SPUR, "T.SPUR",
    /// `T.TAL`: 
    T_TAL, "T.TAL",
    /// `T.TRGD`: 
    T_TRGD, "T.TRGD",
    /// `T.TRR`: 
    T_TRR, "T.TRR",
    /// `T.UPLD`: 
    T_UPLD, "T.UPLD",
    /// `T.VAL`: 
    T_VAL, "T.VAL",
    /// `T.VALG`: 
    T_VALG, "T.VALG",
    /// `T.VALS`: 
    T_VALS, "T.VALS",
    /// `T.VALX`: 
    T_VALX, "T.VALX",
    /// `T.VLC`: 
    T_VLC, "T.VLC",
    /// `U`: undersea
    U, "U",
    /// `U.APNU`: 
    U_APNU, "U.APNU",
    /// `U.ARCU`: 
    U_ARCU, "U.ARCU",
    /// `U.ARRU`: 
    U_ARRU, "U.ARRU",
    /// `U.BDLU`: 
    U_BDLU, "U.BDLU",
    /// `U.BKSU`: 
    U_BKSU, "U.BKSU",
    /// `U.BNCU`: 
    U_BNCU, "U.BNCU",
    /// `U.BNKU`: 
    U_BNKU, "U.BNKU",
    /// `U.BSNU`: 
    U_BSNU, "U.BSNU",
    /// `U.CDAU`: 
    U_CDAU, "U.CDAU",
    /// `U.CNSU`: 
    U_CNSU, "U.CNSU",
    /// `U.CNYU`: 
    U_CNYU, "U.CNYU",
    /// `U.CRSU`: 
    U_CRSU, "U.CRSU",
    /// `U.DEPU`: 
    U_DEPU, "U.DEPU",
    /// `U.EDGU`: 
    U_EDGU, "U.EDGU",
    /// `U.ESCU`: 
    U_ESCU, "U.ESCU",
    /// `U.FANU`: 
    U_FANU, "U.FANU",
    /// `U.FLTU`: 
    U_FLTU, "U.FLTU",
    /// `U.FRKU`: 
    U_FRKU, "U.FRKU",
    /// `U.FRSU`: 
    U_FRSU, "U.FRSU",
    /// `U.FRZU`: 
    U_FRZU, "U.FRZU",
    /// `U.FURU`: 
    U_FURU, "U.FURU",
    /// `U.GAPU`: 
    U_GAPU, "U.GAPU",
    /// `U.GLYU`: 
    U_GLYU, "U.GLYU",
    /// `U.HLLU`: 
    U_HLLU, "U.HLLU",
    /// `U.HLSU`: 
    U_HLSU, "U.HLSU",
    /// `U.HOLU`: 
    U_HOLU, "U.HOLU",
    /// `U.KNLU`: 
    U_KNLU, "U.KNLU",
    /// `U.KNSU`: 
    U_KNSU, "U.KNSU",
    /// `U.LDGU`: 
    U_LDGU, "U.LDGU",
    /// `U.LEVU`: 
    U_LEVU, "U.LEVU",
    /// `U.MDVU`: 
    U_MDVU, "U.MDVU",
    /// `U.MESU`: 
    U_MESU, "U.MESU",
    /// `U.MNDU`: 
    U_MNDU, "U.MNDU",
    /// `U.MOTU`: 
    U_MOTU, "U.MOTU",
    /// `U.MTSU`: 
    U_MTSU, "U.MTSU",
    /// `U.MTU`: 
    U_MTU, "U.MTU",
    /// `U.PKSU`: 
    U_PKSU, "U.PKSU",
    /// `U.PKU`: 
    U_PKU, "U.PKU",
    /// `U.PLFU`: 
    U_PLFU, "U.PLFU",
    /// `U.PLNU`: 
    U_PLNU, "U.PLNU",
    /// `U.PLTU`: 
    U_PLTU, "U.PLTU",
    /// `U.PNLU`: 
    U_PNLU, "U.PNLU",
    /// `U.PRVU`: 
    U_PRVU, "U.PRVU",
    /// `U.RAVU`: 
    U_RAVU, "U.RAVU",
    /// `U.RDGU`: 
    U_RDGU, "U.RDGU",
    /// `U.RDSU`: 
    U_RDSU, "U.RDSU",
    /// `U.RFSU`: 
    U_RFSU, "U.RFSU",
    /// `U.RFU`: 
    U_RFU, "U.RFU",
    /// `U.RISU`: 
    U_RISU, "U.RISU",
    /// `U.RMPU`: 
    U_RMPU, "U.RMPU",
    /// `U.RNGU`: 
    U_RNGU, "U.RNGU",
    /// `U.SCNU`: 
    U_SCNU, "U.SCNU",
    /// `U.SCSU`: 
    U_SCSU, "U.SCSU",
    /// `U.SDLU`: 
    U_SDLU, "U.SDLU",
    /// `U.SHFU`: 
    U_SHFU, "U.SHFU",
    /// `U.SHLU`: 
    U_SHLU, "U.SHLU",
    /// `U.SHSU`: 
    U_SHSU, "U.SHSU",
    /// `U.SHVU`: 
    U_SHVU, "U.SHVU",
    /// `U.SILU`: 
    U_SILU, "U.SILU",
    /// `U.SLPU`: 
    U_SLPU, "U.SLPU",
    /// `U.SMSU`: 
    U_SMSU, "U.SMSU",
    /// `U.SMU`: 
    U_SMU, "U.SMU",
    /// `U.SPRU`: 
    U_SPRU, "U.SPRU",
    /// `U.TERU`: 
    U_TERU, "U.TERU",
    /// `U.TMSU`: 
    U_TMSU, "U.TMSU",
    /// `U.TMTU`: 
    U_TMTU, "U.TMTU",
    /// `U.TNGU`: 
    U_TNGU, "U.TNGU",
    /// `U.TRGU`: 
    U_TRGU, "U.TRGU",
    /// `U.TRNU`: 
    U_TRNU, "U.TRNU",
    /// `U.VALU`: 
    U_VALU, "U.VALU",
    /// `U.VLSU`: 
    U_VLSU, "U.VLSU",
    /// `V`: forest, heath, ...
    V, "V",
    /// `V.BUSH`: 
    V_BUSH, "V.BUSH",
    /// `V.CULT`: 
    V_CULT, "V.CULT",
    /// `V.FRST`: 
    V_FRST, "V.FRST",
    /// `V.FRSTF`: 
    V_FRSTF, "V.FRSTF",
    /// `V.GRSLD`: 
    V_GRSLD, "V.GRSLD",
    /// `V.GRVC`: 
    V_GRVC, "V.GRVC",
    /// `V.GRVO`: 
    V_GRVO, "V.GRVO",
    /// `V.GRVP`: 
    V_GRVP, "V.GRVP",
    /// `V.GRVPN`: 
    V_GRVPN, "V.GRVPN",
    /// `V.HTH`: 
    V_HTH, "V.HTH",
    /// `V.MDW`: 
    V_MDW, "V.MDW",
    /// `V.OCH`: 
    V_OCH, "V.OCH",
    /// `V.SCRB`: 
    V_SCRB, "V.SCRB",
    /// `V.TREE`: 
    V_TREE, "V.TREE",
    /// `V.TUND`: 
    V_TUND, "V.TUND",
    /// `V.VIN`: 
    V_VIN, "V.VIN",
    /// `V.VINS`: 
    V_VINS, "V.VINS",
    /// `Wikipedia Article`: A Wikipedia article
    WikipediaArticle, "WikipediaArticle",
    /// `alternateName`: 
    alternateName, "alternateName",
    /// `children features`: Links to an RDF document containing the descriptions of children features
    childrenFeatures, "childrenFeatures",
    /// `colloquial name`: 
    colloquialName, "colloquialName",
    /// `ISO country code`: A two letters country code in the ISO 3166 list
    countryCode, "countryCode",
    /// `feature class`: The main category of the feature, as defined in geonames taxonomy.
    featureClass, "featureClass",
    /// `feature code`: Type of the feature, as defined in geonames taxonomy.
    featureCode, "featureCode",
    /// `geonames identifier`: 
    geonamesID, "geonamesID",
    /// `historical name`: 
    historicalName, "historicalName",
    /// `located in`: Indicates that the subject resource is located in the object feature
    locatedIn, "locatedIn",
    /// `map`: A geonames map centered on the feature.
    locationMap, "locationMap",
    /// `name`: The main international name of a feature. The value has no xml:lang tag.
    name, "name",
    /// `nearby`: A feature close to the reference feature
    nearby, "nearby",
    /// `nearby features`: Links to an RDF document containing the descriptions of nearby features
    nearbyFeatures, "nearbyFeatures",
    /// `neighbour`: A feature sharing a common boarder with the reference feature
    neighbour, "neighbour",
    /// `neighbouring features`: Links to an RDF document containing the descriptions of neighbouring features. Applies when the feature has definite boarders.
    neighbouringFeatures, "neighbouringFeatures",
    /// `official name`: A name in an official local language
    officialName, "officialName",
    /// `level 1 administrative parent`: 
    parentADM1, "parentADM1",
    /// `level 2 administrative parent`: 
    parentADM2, "parentADM2",
    /// `level 3 administrative parent`: 
    parentADM3, "parentADM3",
    /// `level 4 administrative parent`: 
    parentADM4, "parentADM4",
    /// `parent country`: 
    parentCountry, "parentCountry",
    /// `parent feature`: A feature parent of the current one, in either administrative or physical subdivision.
    parentFeature, "parentFeature",
    /// `population`: 
    population, "population",
    /// `postal code`: 
    postalCode, "postalCode",
    /// `short name`: 
    shortName, "shortName",
    /// `wikipedia article`: A Wikipedia article of which subject is the resource.
    wikipediaArticle, "wikipediaArticle"
);
